package pseuco.javaCompiler

/**
 * An exception indicating an error within a pseuCo program.
 * Holds either a [message] or a [cause].
 *
 * @constructor Creates a new exception.
 * @param message The compiler error message.
 * @param cause The actual exception generated by the compiler.
 */
class PseuCoCompilerError private constructor(message: String?, cause: Throwable?) : Exception(message, cause) {

    /**
     * Creates a new exception holding a compiler error message.
     *
     * @author Konstantin Kopper
     * @since 2.1
     */
    constructor(message: String) : this(message, null)

    /**
     * Creates a new exception holding an exception thrown by the compiler.
     *
     * @author Konstantin Kopper
     * @since 2.1
     */
    constructor(cause: Throwable) : this(null, cause)

    override fun toString(): String = message ?: ""
}
